=========
Changelog
=========

Version 0.1.4
=============

Initial release

* FEATURE: Support for new semantic similarity model
* DEMO: Semantic anomaly detection

Version 0.1.3
=============

Initial release

* FEATURE: Embedding Indices
* DEMO: Chatbot Harness